@@ -11,17 +11,9 @@ __PACKAGE__->table_class('DBIx::Class::ResultSource::View');
 __PACKAGE__->table("port_macs");
 __PACKAGE__->result_source_instance->is_virtual(1);
 __PACKAGE__->result_source_instance->view_definition(<<ENDSQL
-  SELECT dp.ip, dp.mac
-
-  FROM
-    (SELECT ip, mac FROM device
+    SELECT ip, mac FROM device where mac = any (?::macaddr[])
       UNION
-    SELECT ip, mac FROM device_port) dp
-
-  INNER JOIN
-    (SELECT unnest( ? ::macaddr[] )) locals(m)
-    ON (dp.mac = locals.m ::macaddr)
-
+    SELECT ip, mac FROM device_port dp where mac = any (?::macaddr[])
 ENDSQL
 );
 
